@@ -23,12 +23,7 @@
 #ifndef PSYNTH_VERSION_H
 #define PSYNTH_VERSION_H
 
-#define PSYNTH_VERSION     "0.1.3"
-
-#define PSYNTH_DATA_DIR    "/usr/local/share/psychosynth"
-#define PSYNTH_LIB_DIR     "/usr/local/lib"
-#define PSYNTH_BIN_DIR     "/usr/local/bin"
-#define PSYNTH_INCLUDE_DIR "/usr/local/include/libpsynth"
+#define PSYNTH_VERSION     "0.1.4"
 
 #if 1
 #define PSYNTH_HAVE_ALSA 1
